
-- convenience iteration
map = function(list, func, ...)
	for i=1, #list do
		func(list[i], ...)
	end
end

-- same as map, returns true to keep, false to remove
sweep = function(list, func, ...)
	for i=#list, 1, -1 do
		if not func(list[i], ...) then
			table.remove(list, i)
		end
	end
end

-- used for finding an element with specific criteria
find = function(list, func, ...)
	for i=1, #list do
		local result = func(list[i])
		if result then
			return result
		end
	end
end

-- use with above function, makes a function to find a specific object
searchFor = function(value)
	return function(i)
		return i == value
	end
end

-- convenience instantation
new = function(parent, ...)
	local instance = setmetatable({}, { __index = parent })
	instance.__parent = parent
	parent.init(instance, ...)
	return instance
end

-- reverse the result of a function
inverse = function(func)
	return function(...)
		return not func(...)
	end
end

-- make a PO2 canvas
function po2Canvas(width, height)
	local canvasWidth = 2 ^ math.ceil(math.log(width) / math.log(2))
	local canvasHeight = 2 ^ math.ceil(math.log(height) / math.log(2))
	print(canvasWidth, canvasHeight)
	return love.graphics.newCanvas(canvasWidth, canvasHeight)
end
